#
# spec file for package tail-tray
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tail-tray
Version:        0.2.23
Release:        1.1
Summary:        Tailscale tray menu and UI for the KDE Plasma Desktop
License:        GPL-3.0-only
URL:            https://github.com/SneWs/tail-tray
Source:         %{name}-%{version}.tar.gz
BuildRequires:  clang
BuildRequires:  cmake >= 3.21
%if 0%{?suse_version} < 1600
BuildRequires:  gcc14-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake(Qt6Core) >= 6.7
BuildRequires:  cmake(Qt6Linguist) >= 6.7
BuildRequires:  cmake(Qt6Network) >= 6.7
BuildRequires:  cmake(Qt6Test) >= 6.7
BuildRequires:  cmake(Qt6Tools) >= 6.7
BuildRequires:  cmake(Qt6Widgets) >= 6.7
BuildRequires:  pkgconfig(openssl)
Requires:       tailscale
Suggests:       davfs2

%description
Tailscale tray menu and UI for Plasma Desktop

Features

- Control your Tailscale connection from the tray
- Show IPs
- Show current connection status of your devices
- Overview of your network and network status
- Set and change your Tailscale exit node
- Proper multi account handling
- Tail drive support - Working with davfs2 support + additional help setting up
  davfs2 and mounting etc
- Send files to any device on your Tailnet directly from the tray menu
- Get notified and receive files from any device on your Tailnet to a
  pre-defined location on disk

%prep
%autosetup

%build
%if 0%{?suse_version} < 1600
export CC="/usr/bin/gcc14"
export CXX="/usr/bin/g++-14"
%endif
%cmake
%cmake_build

%install
%cmake_install

sed -i 's#/usr/local/bin/tail-tray#/usr/bin/tail-tray#g' %{buildroot}%{_datadir}/applications/%{name}.desktop
sed -i 's#Networking;##g' %{buildroot}%{_datadir}/applications/%{name}.desktop
sed -i 's#VPN;##g' %{buildroot}%{_datadir}/applications/%{name}.desktop
sed -i 's#Internet;##g' %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/128x128/apps/tailscale.png
%{_datadir}/applications/%{name}.desktop
%{_libdir}/%{name}

%changelog
* Tue Jun  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.2.23:
  * What's new in this release 🎉
  - This release adds support for better handling of Mullvad exit
    nodes, bug fixes and minor tweaks.
    It's also the first release that officially package for
    Ubuntu 25.04
  * Commits
  - e55b78e: Issue #77 - Support for Ubuntu 25.04 (Plucky Puffin)
    (Marcus Grenängen)
  - 8994b79: Build from source: knotifications instructions
    (Marcus Grenängen)
  - c5a40a4: Let's see if this is the correct path ref inside the
    container (Marcus Grenängen)
  - 19639bb: More tests to see if it solves it (Marcus Grenängen)
  - b2ffba4: And fix 24.04 and Debian Trixie builds as well
    (Marcus Grenängen)
  - 03d3e4b: And some more minor workflow fixes (Marcus
    Grenängen)
  - fb9e088: More workflow fixes (Marcus Grenängen)
  - 8099605: Permission fixes for 24.04 and Trixie outputs
    (Marcus Grenängen)
  - 5b97ed5: Extra install deps for builds (Marcus Grenängen)
  - c0640f0: Fix Trixie build & build names (Marcus Grenängen)
  - af40020: [Issue #76] - First pass on getting basic support
    for Mullvad exit nodes (#78) (Marcus Grenängen) #78
  - 1dbe121: Fix for windows build uploads (Marcus Grenängen)
  - 0664616: Add ubuntu-25.04-plucky to tagged release builds
    (Marcus Grenängen)
  - b693b3c: Bump version to 0.2.23 (Marcus Grenängen)
* Wed May  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.2.22:
  * What's new in this release
    This release has some new Notification handling if you are
    building and running it for KDE Plasma 6 or later, using this
    feature will give you fancy notification integrations into your
    Plasma Desktop.
    It also comes with the regular flow of bug fixes, most notable
    are fixes around potential segfaults, that hopefully should be
    fully resolved now
  * Commits
  - [Issue #36] - Use KNotification framework for notifications
    (#73) (Marcus Grenängen) #73
  - Test to build on kdeneon/plasma:user (Marcus Grenängen)
  - Revert "Test to build on kdeneon/plasma:user" (Marcus
    Grenängen)
  - gh runner (Marcus Grenängen)
  - Revert "gh runner" (Marcus Grenängen)
  - KNOTIFICATIONS_ENABLED=OFF to have it still build for ubuntu
    24.04 and Debian stable (Marcus Grenängen)
  - Fix for potential segfault due to double free + code
    readability fix/cleanup (Marcus Grenängen)
  - Ignore .cache dir (Marcus Grenängen)
  - Fix segfault for Issue #75 (Marcus Grenängen)
  - Bump version to 0.2.22 (Marcus Grenängen)
* Tue Apr 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.2.21:
  * What's new in this release
    This is a smaller service release focusing on fixing reported
    bugs and further stability improvements and memory usage
    improvements.
    It also comes with
  - A new login flow + UI
  - Better checking and prompting if tailscale isn't installed or
    can't be found through a users PATH
  - Single instance mode, we'll now detect and enforce a single
    instance of Tail Tray
  - Translation updates and additions where translations where
    missing for DE, FR and SE
  * Commits
  - fabfe68: When waiting for login, show cancel dialog #62 (#68)
    (Marcus Grenängen) #68
  - 07f5cd7: Warn if Tailscale isn't installed #66 (#69) (Marcus
    Grenängen) #69
  - 6969c62: [Fix] - Unknown CMake command "qt_add_executable"
    when trying to build on Arch Linux #70 (Marcus Grenängen)
  - 453ad33: Repeated prompts to set myself as operator #67
    (Marcus Grenängen)
  - 9d5f76b: Enforce single application instance #71 (Marcus
    Grenängen)
  - d9be255: [Feature] - Better please wait dlg (#72) (Marcus
    Grenängen) #72
  - 04156c2: Minor optimization and alignment + correctness
    (Marcus Grenängen)
  - 8edadc8: Translation updates and additions (Marcus Grenängen)
  - 5bf5ad3: Bump version to 0.2.21 (Marcus Grenängen)
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 0.2.20:
  * Bump version to 0.2.20
  * And one more memory optimization + code correctness fixes
  * TailStatus - Pass by ref and avoid heap allocs
  * Improved memory usage part 2/2
  * Improved memory usage part 1/2
  * Don't leak current prefs
  * Minor optimization and cleanup around process execution
  * Some more fixes
  * Use std::vector instead of QList for TailDeviceInfo list
  * Don't leak QTableWidgetItem's
  * Minor log silence
  * Tailscale update / auto update settings & command options
* Wed Apr  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.2.19:
  * Bump version to 0.2.19
  * Adding IpnEventData and expose it over event bus (#59)
* Wed Mar 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.18:
  * Bump version to 0.2.18
  * Add Ipn watcher - Issue #57 (#58)
  * Fix issue where we would not apply setting --accept-routes
    (#56)
  * Fix for opening in file manager
  * Move TailDrive related UI code out to a separate manager
  * Minor fixes, renames and code correctness (#53)
  * Make sure to terminate any pending processes when user wants to
    quit
* Sat Mar  1 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.17:
  * What's new in this release
  - More UI fixes in the ongoing effort to clean up and make the
    UI better.
  - Build pipeline fixes, release and dev builds should output
    the target names in deb files correctly now
  * Commits
  - Fixes for main settings UI (#52) (Marcus Grenängen) #52
  - Ubuntu and Debian build changes (Marcus Grenängen)
  - Skip 24.10 builds (Marcus Grenängen)
  - Update version to 0.2.17 (Marcus Grenängen)
  - Release build pipeline - Try improving the deb names
    outputted (Marcus Grenängen)
* Tue Feb 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.16:
  * Bump version to 0.2.16
  * UI/UI fixes for older qt (#50)
  * update nix-os.md (#51)
* Fri Feb 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.15:
  * Bump version to 0.2.15
  * Hot fix: Crash when no entries in dns status fix for #49
* Thu Feb 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.14:
  * Bump version to 0.2.14
  * Fix #48 - Cannot select "None" as Exit Node
  * README re-structure and moving into sub-pages etc
  * update README.md (#47)
  * Fix compile error on Debian/Ubuntu with older QT version
  * Tailscale DNS settings UI #35 (#46)
  * More github runner cleanups
  * Use different QT versions for Linux and Windows
  * UI polish of Settings window layouts etc (#45)
  * Add advertiseRoutes in TailRunner (#44)
  * Update Linux CMake build steps a bit
  * Main layout - Fix account button + list layout a bit
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.13:
  * Bump version to 0.2.13
  * Update Debian packaging (#42)
  * Fix missing cases for Command to str
  * README - Update Windows sections
  * Windows Builds - Add resource file getting exe file to show
    icon
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.12:
  * Bump version to 0.2.12
  * Windows Fixes + Icon Fixes (#40)
  * Re-add the timeout that got remove
  * Bug fix: Make sure to bootstrap when re-connected
* Thu Feb 13 2025 opensuse_buildservice@ojkastl.de
- Update to version latest:
  * Bump version to 0.2.11
  * Feature - Use tailscale settings reader + fix login / logged
    out flows (#39)
  * Bugs/issue 37 (#38)
  * Update README and include link + info about Windows binaries
  * Network state checking - Check every 2 minutes
  * One last try with this crap
  * God I hate github workflow
  * Wrap in "" for $PREV_TAG
  * Reading tag changes - Wrong ordering of commands
  * And fix git config for pushing tags
  * Better tag handling for change log
  * Let's see if changes is updated in Release page now
  * Forgot to update latest and push it
  * Only update latest changelog when running on Linux builder
  * Windows - Fix look & feel - No need for custom style override
  * Gah, missed one
  * Windows artifacts - Minor name changes
  * Update change log for latest release + upload binaries
  * Missing clobber on windows
  * No need to create release, just update/upload
  * Artifacts and build simplifications
  * Linux fix
  * And lets try to use gh cli to upload to the release tag
  * Lets try actions/upload-artifact@v4 instead of
    marvinpinto/action-automatic-releases@latest
  * More publishing fixes and trouble shooting
  * Windows build debug tests
  * More windows publishing debug
  * More windows publishing artifact fixes + use 7zip for solid
    archive mgmt
  * Publishing fixes for Windows and artifacts
  * Combined artifacts upload
  * Re-enable copy of build artifacts for windows
  * Re-enable and fix up Windows package flow after build
  * Github runner: Disable windows package & publish for now
  * Github runner: pwsh for all windows things + cleanups
  * Github runner: pwsh for all windows things
  * Github runner: pwsh for all windows things
  * Github runner: pwsh for all windows things
  * Try pwsh on windows
  * Don't install build tools on windows
  * Github runner: CMake ubuntu fixes
  * More windows build fixes
  * VS 2022
  * Github runner - Try adding windows builds
  * Fix issue #33 BUG: Automatic reconect after disconecting
  * Enable compile commands
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.10:
  * Bump version to 0.2.10
  * Tail drive - bug fixes (#31)
  * Update README.md (#30)
* Fri Jan 31 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.9:
  * Bump version to 0.2.9
  * Fix #26 - Be able to toggle davfs dep via cmake and update
    README (#29)
* Wed Jan 29 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.8:
  * Bump version to 0.2.8 and prepare for new release
  * remove permission set from cmake-multi-platform.yml
  * Fix for #27 - BufferedProcessWrapper
  * Quick workaround to make sure we don't read process output
    until the process is flagged complete
  * Tailscale data parsing - More cleanup and fixes
  * Tailscale data parsing - Better value checking and handling
  * Add extra Debug output for issue #27
  * Remove permission definition for tagged release
  * Make it writeable for pushing release tags
  * Fix CodeQL scanner alerts for github jobs
  * Add AUR package to getting started section
  * README - Add sections for building on Windows
  * Correctness - Make sure to run completed cleanup in dtor
  * Windows - Don't use alternating row colors as it looks like ass
    on Windows
* Fri Nov 29 2024 Richard Rahl <rrahl0@opensuse.org>
- set minimum version for various BuildRequires
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.7:
  * Include translation files when making deb pkg
  * Implement translations #19
  * UI Fixes - Should be rich text for tail drive help text
  * Windows - Force Fusion style on Windows builds
  * UI cleanup and fixes
  * Code cleanup and structure
  * Bug fix: Make sure to start if we're not connected
* Thu Nov 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.6:
  * Bump version to 0.2.6
  * Bug fix: Do not add multiple separators after the account in
    connected state menu
  * Exit nodes - Add offline (and tag as offline + disabled) in
    Exit node menu
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.5:
  * Bump version to v0.2.5
  * Last letter is missing for all clients #20
  * Last letter is missing for all clients #20
  * Network status overview - Inject latency for fastest DERP in
    overview list
  * Windows - Impl windows specific for restart dns and restart
    tailscale service
  * CMake additions for Windows builds + TailRunner additions to
    not do some things on Windows
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.4:
  * Bump version to v0.2.4
  * Add information toast when connecting to tail tray from menu
    action
  * Better tailscale command invocations that runs each command as
    a separate process
  * Bug fix: Make sure to early out if not 0 exit code for file
    receive process
  * Bug fix: Make sure to check the self online state for correct
    state updates
  * Fix application name in Toast messages etc to be Tail Tray
    instead of the cmd name tail-tray
  * Fix File receiver - Add `--verbose` to get the file name info
    for notification data
  * Scan for missing operator ownership and recommend to set user
    as operator.
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.3:
  * Bump version to v0.2.3
  * Fix application name in Toast messages etc to be Tail Tray
    instead of the cmd name tail-tray
  * Fix File receiver - Add `--verbose` to get the file name info
    for notification data
  * Scan for missing operator ownership and recommend to set user
    as operator.
  * Fix Fedora dependency install command
  * Update README.md
  * Bump version to 0.2.2
  * Fix settings window to be wider + fix issue with resource file
    since file moves
  * Make it build and look somewhat proper on macOS
  * Fix settings window to be wider + fix issue with resource file
    since file moves
  * Make it build and look somewhat proper on macOS
  * Bug fix: Don't close application when window closes
* Sun Oct 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package tail-tray: Tailscale tray menu and UI for the KDE
  Plasma Desktop
